@@ -1,11 +1,8 @@
-/*  Scheduler Unit test.
-    Copyright (C) 2021 Hy Murveit
+/*
+    SPDX-FileCopyrightText: 2021 Hy Murveit <hy@murveit.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /*
  * This file contains unit tests for the scheduler, in particular for the
@@ -116,6 +113,10 @@ TestSchedulerUnit::TestSchedulerUnit() : QObject()
     // There's some slight complexity when setting near the altitude constraint.
     // This is not tested yet.
     Options::setSettingAltitudeCutoff(0);
+
+    // Setting this true winds up calling KStarsData::Instance() in the scheduler via SkyPoint::apparentCoord().
+    // Unit tests don't instantiate KStarsData::Instance() and will crash.
+    Options::setUseRelativistic(false);
 }
 
 // Tests that the doubles are within tolerance.
