@@ -1,20 +1,8 @@
+/*
+    SPDX-FileCopyrightText: 2008 Akarsh Simha <akarshsimha@gmail.com>
 
-/***************************************************************************
-                   binfilehelper.cpp - K Desktop Planetarium
-                             -------------------
-    begin                : Sat May 31 2008
-    copyright            : (C) 2008 by Akarsh Simha
-    email                : akarshsimha@gmail.com
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "binfilehelper.h"
 
