@@ -1,19 +1,8 @@
-/***************************************************************************
-                          ksfilereader.h  -  description
-                             -------------------
-    begin                : 2007-07-16
-    copyright            : (C) 2007 James B. Bowlin
-    email                : bowlin@mindspring.com
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 James B. Bowlin <bowlin@mindspring.com>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
