@@ -1,18 +1,7 @@
-/** *************************************************************************
-                          kspaths.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : 20/05/2016
-    copyright            : (C) 2016 by Artem Fedoskin
-    email                : afedoskin3@gmail.com
- ***************************************************************************/
-/** *************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2016 Artem Fedoskin <afedoskin3@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "auxiliary/kspaths.h"
 #include <QFileInfo>
