@@ -1,20 +1,9 @@
+/*
+    SPDX-FileCopyrightText: Thomas Kabelmann
+    SPDX-FileCopyrightText: 2018 Robert Lancaster <rlancaste@gmail.com>
 
-/***************************************************************************
-                          XPlanetImageviewer.cpp  -  Based on: KStars Image Viwer by Thomas Kabelmann
-                             -------------------
-    begin                : Sun Aug 12, 2018
-    copyright            : (C) 2018 by Robert Lancaster
-    email                : rlancaste@gmail.com
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "xplanetimageviewer.h"
 #include "Options.h"
