@@ -1,19 +1,8 @@
-/***************************************************************************
-                          detaildialog.cpp  -  description
-                             -------------------
-    begin                : Sun May 5 2002
-    copyright            : (C) 2002 by Jason Harris and Jasem Mutlaq
-    email                : kstars@30doradus.org
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002 Jason Harris and Jasem Mutlaq <kstars@30doradus.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "detaildialog.h"
 
