@@ -1,10 +1,7 @@
 /*  Ekos Mount MOdel
-    Copyright (C) 2018 by Robert Lancaster
+    SPDX-FileCopyrightText: 2018 Robert Lancaster
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "mountmodel.h"
@@ -1078,7 +1075,7 @@ void MountModel::startAlignmentPoint()
         QTableWidgetItem *raCell = alignTable->item(currentAlignmentPoint, 0);
         QString raString         = raCell->text();
         dms raDMS                = dms::fromString(raString, false);
-        double ra                = raDMS.Hours();
+        double raDeg             = raDMS.Degrees();
 
         QTableWidgetItem *decCell = alignTable->item(currentAlignmentPoint, 1);
         QString decString         = decCell->text();
@@ -1089,7 +1086,8 @@ void MountModel::startAlignmentPoint()
         alignTable->setCellWidget(currentAlignmentPoint, 3, alignIndicator);
         alignIndicator->startAnimation();
 
-        m_AlignInstance->setTargetCoords(ra, dec);
+        const SkyObject *target = getWizardAlignObject(raDeg, dec);
+        m_AlignInstance->setTarget(*target, *target);
         m_AlignInstance->Slew();
     }
 }
