@@ -1,10 +1,7 @@
-/*  Ekos Port Selector
-    Copyright (C) 2021 Jasem Mutlaq <mutlaqja@ikarustech.com>
+/*
+    SPDX-FileCopyrightText: 2021 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "portselector.h"
@@ -212,12 +209,24 @@ bool Device::initGUI()
 //////////////////////////////////////////////////////////////////////////////////////////
 void Device::syncGUI()
 {
+    // Check if initGUI failed before?
+    if (m_LED == nullptr)
+    {
+        // Try to initiGUI again
+        initGUI();
+
+        // If it failed again, return.
+        if (m_LED == nullptr)
+            return;
+    }
+
     m_LED->setColor(ColorCode.value(m_Device->getState("CONNECTION")));
 
     INDI::PropertyView<ISwitch> connectionMode = *(m_Device->getBaseDevice()->getSwitch("CONNECTION_MODE"));
 
     if (connectionMode.findOnSwitchIndex() == CONNECTION_SERIAL)
     {
+        m_ActiveConnectionMode = CONNECTION_SERIAL;
         m_SerialB->setStyleSheet(ACTIVE_STYLESHEET);
         m_NetworkB->setStyleSheet(QString());
 
@@ -235,6 +244,7 @@ void Device::syncGUI()
     }
     else
     {
+        m_ActiveConnectionMode = CONNECTION_NETWORK;
         m_SerialB->setStyleSheet(QString());
         m_NetworkB->setStyleSheet(ACTIVE_STYLESHEET);
 
@@ -281,6 +291,8 @@ uint8_t Device::systemPortCount() const
 //////////////////////////////////////////////////////////////////////////////////////////
 void Device::setConnectionMode(ConnectionMode mode)
 {
+    m_ActiveConnectionMode = mode;
+
     if (mode == CONNECTION_SERIAL)
     {
         if (m_HostName)
@@ -417,8 +429,24 @@ bool Dialog::shouldShow() const
     if (m_Devices.empty())
         return false;
 
-    // If we only have one device with single port, then no need to show dialog
-    if (m_Devices.size() == 1 && m_Devices[0]->systemPortCount() == 1)
+    uint32_t systemPortCount = 0;
+    uint32_t serialDevices = 0;
+    uint32_t networkDevices = 0;
+
+    for (const auto &oneDevice : m_Devices)
+    {
+        if (oneDevice->systemPortCount() > 0)
+            systemPortCount = oneDevice->systemPortCount();
+
+        if (oneDevice->activeConnectionMode() == CONNECTION_SERIAL)
+            serialDevices++;
+        else if (oneDevice->activeConnectionMode() == CONNECTION_NETWORK)
+            networkDevices++;
+    }
+
+    // If we just have a single serial device with single port, no need to toggle port selector.
+    // If have have one or more network devices, we must show the dialog for the first time.
+    if (networkDevices == 0 && serialDevices <= 1 && systemPortCount <= 1)
         return false;
 
     // Otherwise, show dialog
