@@ -9,11 +9,10 @@
 #include "ui_captureprocessoverlay.h"
 
 #include "indi/indicommon.h"
+#include "fitsviewer/fitsdata.h"
 
 #include <QWidget>
 
-class FITSData;
-
 class CaptureProcessOverlay : public QWidget,  public Ui::CaptureProcessOverlay
 {
     Q_OBJECT
@@ -29,8 +28,8 @@ public:
         QString filterName;
         QString filename;
         double exptime;
-        double targetdrift;
-        QPoint binning;
+        int xBin;
+        int yBin;
         int width;
         int height;
         double gain;
@@ -67,7 +66,6 @@ public:
          * @brief the currently pointed capture frame
          */
         const FrameData currentFrame() {return m_history.at(m_position);}
-
         /**
          * @brief The current navigation position in the capture history
          */
@@ -123,12 +121,6 @@ public:
      */
     void updateFrameData();
 
-    /**
-     * @brief Update the current target distance.
-     * @param targetDiff distance to the target in arcseconds.
-     */
-    void updateTargetDistance(double targetDiff);
-
     /**
      * @brief Obtain the position of the current frame from the history
      */
