@@ -1,11 +1,8 @@
-/*  Ekos
-    Copyright (C) 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
+/*
+    SPDX-FileCopyrightText: 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "sequencejob.h"
 
@@ -366,14 +363,21 @@ SequenceJob::CAPTUREResult SequenceJob::capture(bool autofocusReady)
 {
     activeChip->setBatchMode(!preview);
 
-    if (localDirectory.isEmpty() == false)
-        activeCCD->setFITSDir(localDirectory + directoryPostfix);
-
     activeCCD->setISOMode(timeStampPrefixEnabled);
 
     activeCCD->setSeqPrefix(fullPrefix);
 
-    activeCCD->setUploadMode(uploadMode);
+    auto placeholderPath = Ekos::PlaceholderPath(localDirectory + "/sequence.esq");
+    placeholderPath.setGenerateFilenameSettings(*this);
+    activeCCD->setPlaceholderPath(placeholderPath);
+
+    if (preview)
+    {
+        if (activeCCD->getUploadMode() != ISD::CCD::UPLOAD_CLIENT)
+            activeCCD->setUploadMode(ISD::CCD::UPLOAD_CLIENT);
+    }
+    else
+        activeCCD->setUploadMode(uploadMode);
 
     QMapIterator<QString, QMap<QString, double>> i(customProperties);
     while (i.hasNext())
