@@ -1,13 +1,9 @@
-/*  Ekos Live Media
-
-    Copyright (C) 2018 Jasem Mutlaq <mutlaqja@ikarustech.com>
+/*
+    SPDX-FileCopyrightText: 2018 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
     Media Channel
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "media.h"
@@ -72,8 +68,8 @@ void Media::onConnected()
 {
     qCInfo(KSTARS_EKOS) << "Connected to media Websocket server at" << m_URL.toDisplayString();
 
-    connect(&m_WebSocket, &QWebSocket::textMessageReceived,  this, &Media::onTextReceived);
-    connect(&m_WebSocket, &QWebSocket::binaryMessageReceived, this, &Media::onBinaryReceived);
+    connect(&m_WebSocket, &QWebSocket::textMessageReceived,  this, &Media::onTextReceived, Qt::UniqueConnection);
+    connect(&m_WebSocket, &QWebSocket::binaryMessageReceived, this, &Media::onBinaryReceived, Qt::UniqueConnection);
 
     m_isConnected = true;
     m_ReconnectTries = 0;
@@ -305,24 +301,23 @@ void Media::upload(FITSView * view)
     // For low bandwidth images
     if (!m_Options[OPTION_SET_HIGH_BANDWIDTH] || m_UUID[0] == "+")
     {
-        QPixmap scaledImage = view->getDisplayPixmap().scaledToWidth(HB_WIDTH / 2, Qt::FastTransformation);
+        QPixmap scaledImage = view->getDisplayPixmap().width() > HB_IMAGE_WIDTH / 2 ?
+                              view->getDisplayPixmap().scaledToWidth(HB_IMAGE_WIDTH / 2, Qt::FastTransformation) :
+                              view->getDisplayPixmap();
         scaledImage.save(&buffer, ext.toLatin1().constData(), HB_IMAGE_QUALITY / 2);
-        //ext = "jpg";
     }
     // For high bandwidth images
     else
     {
-        QImage scaledImage = view->getDisplayImage().scaledToWidth(HB_WIDTH, Qt::SmoothTransformation);
+        QImage scaledImage =  view->getDisplayImage().width() > HB_IMAGE_WIDTH ?
+                              view->getDisplayImage().scaledToWidth(HB_IMAGE_WIDTH, Qt::SmoothTransformation) :
+                              view->getDisplayImage();
         scaledImage.save(&buffer, ext.toLatin1().constData(), HB_IMAGE_QUALITY);
-        //ext = "png";
     }
     buffer.close();
 
     emit newImage(jpegData);
 
-    //m_WebSocket.sendTextMessage(QJsonDocument(metadata).toJson(QJsonDocument::Compact));
-    //m_WebSocket.sendBinaryMessage(jpegData);
-
     if (view == previewImage.get())
         previewImage.reset();
 }
@@ -410,7 +405,9 @@ void Media::sendUpdatedFrame(FITSView *view)
     }
     else
     {
-        scaledImage = view->getDisplayPixmap().scaledToWidth(HB_WIDTH / 2, Qt::FastTransformation);
+        scaledImage = view->getDisplayPixmap().width() > HB_IMAGE_WIDTH / 2 ?
+                      view->getDisplayPixmap().scaledToWidth(HB_IMAGE_WIDTH / 2, Qt::FastTransformation) :
+                      view->getDisplayPixmap();
         emit newBoundingRect(QRect(), QSize(), 100);
     }
 
@@ -424,7 +421,7 @@ void Media::sendVideoFrame(const QSharedPointer<QImage> &frame)
     if (m_isConnected == false || m_Options[OPTION_SET_IMAGE_TRANSFER] == false || m_sendBlobs == false || !frame)
         return;
 
-    int32_t width = m_Options[OPTION_SET_HIGH_BANDWIDTH] ? HB_WIDTH : HB_WIDTH / 2;
+    int32_t width = m_Options[OPTION_SET_HIGH_BANDWIDTH] ? HB_VIDEO_WIDTH : HB_VIDEO_WIDTH / 2;
     QByteArray image;
     QBuffer buffer(&image);
     buffer.open(QIODevice::WriteOnly);
