@@ -1,11 +1,8 @@
-/*  Ekos Focus tool
-    Copyright (C) 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
+/*
+    SPDX-FileCopyrightText: 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
@@ -14,6 +11,7 @@
 #include "ekos/ekos.h"
 #include "ekos/auxiliary/filtermanager.h"
 #include "ekos/auxiliary/stellarsolverprofileeditor.h"
+#include "ekos/auxiliary/darkprocessor.h"
 #include "ekos/mount/mount.h"
 #include "fitsviewer/fitsviewer.h"
 #include "indi/indiccd.h"
@@ -333,6 +331,14 @@ class Focus : public QWidget, public Ui::Focus
              */
         void focusStarSelected(int x, int y);
 
+        /**
+         * @brief selectFocusStarFraction Select the focus star based by fraction of the overall size.
+         * It calls focusStarSelected after multiplying the fractions (0.0 to 1.0) with the focus view width and height.
+         * @param x final x = x * focusview_width
+         * @param y final y = y * focusview_height
+         */
+        void selectFocusStarFraction(double x, double y);
+
         /**
              * @brief newFITS A new FITS blob is received by the CCD driver.
              * @param bp pointer to blob data
@@ -380,8 +386,7 @@ class Focus : public QWidget, public Ui::Focus
         void setMountStatus(ISD::Telescope::Status newState);
 
         // Update Altitude From Mount
-        void setMountCoords(const QString &ra, const QString &dec, const QString &az, const QString &alt, int pierSide,
-                            const QString &ha);
+        void setMountCoords(const SkyPoint &position, ISD::Telescope::PierSide pierSide, const dms &ha);
 
         /**
          * @brief toggleVideo Turn on and off video streaming if supported by the camera.
@@ -408,10 +413,10 @@ class Focus : public QWidget, public Ui::Focus
 
 
 
-protected:
-        void addPlotPosition(int pos, double hfr);
+    protected:
+        void addPlotPosition(int pos, double hfr, bool plot = true);
 
-private slots:
+    private slots:
         /**
              * @brief toggleSubframe Process enabling and disabling subfrag.
              * @param enable If true, subframing is enabled. If false, subframing is disabled. Even if subframing is enabled, it must be supported by the CCD driver.
@@ -426,7 +431,7 @@ private slots:
 
         void processCaptureTimeout();
 
-        void processCaptureFailure();
+        void processCaptureError(ISD::CCD::ErrorType type);
 
         void setCaptureComplete();
 
@@ -475,7 +480,7 @@ private slots:
           * @param pulseDuration Pulse duration in ms for relative focusers that only support timers,
           *        or the number of ticks in a relative or absolute focuser
           * */
-        void newHFRPlotPosition(double pos, double hfr, int pulseDuration);
+        void newHFRPlotPosition(double pos, double hfr, int pulseDuration, bool plot = true);
 
         /**
          * @brief draw the approximating polynomial into the HFR V-graph
@@ -483,14 +488,14 @@ private slots:
          * @param isVShape has the solution a V shape?
          * @param activate make the graph visible?
          */
-        void drawPolynomial(PolynomialFit *poly, bool isVShape, bool activate);
+        void drawPolynomial(PolynomialFit *poly, bool isVShape, bool activate, bool plot = true);
 
         /**
          * @brief Focus solution with minimal HFR found
          * @param solutionPosition focuser position
          * @param solutionValue HFR value
          */
-        void minimumFound(double solutionPosition, double solutionValue);
+        void minimumFound(double solutionPosition, double solutionValue, bool plot = true);
 
         /**
          * @brief redraw the entire HFR plot
@@ -500,6 +505,11 @@ private slots:
          */
         void redrawHFRPlot(PolynomialFit *poly, double solutionPosition, double solutionValue);
 
+        /**
+         * @brief draw a title on the focus plot
+         * @param title the title
+         */
+        void setTitle(const QString &title, bool plot = true);
 
     private:
 
@@ -539,10 +549,16 @@ private slots:
         void autoFocusLinear();
         void autoFocusRel();
 
+        // Linear does plotting differently from the rest.
+        void plotLinearFocus();
+
         /** @brief Helper function determining whether the focuser behaves like a position
          *         based one (vs. a timer based)
          */
-        bool isPositionBased() {return (canAbsMove || canRelMove || (focusAlgorithm == FOCUS_LINEAR));}
+        bool isPositionBased()
+        {
+            return (canAbsMove || canRelMove || (focusAlgorithm == FOCUS_LINEAR));
+        }
         void resetButtons();
         void stop(FocusState completionState = FOCUS_ABORTED);
 
@@ -596,7 +612,7 @@ private slots:
         /**
          * @brief completeAutofocusProcedure finishes off autofocus and emits a message for other modules.
          */
-        void completeFocusProcedure(FocusState completionState);
+        void completeFocusProcedure(FocusState completionState, bool plot = true);
 
         /**
          * @brief activities to be executed after the configured settling time
@@ -734,8 +750,8 @@ private slots:
         int activeBin { 0 };
         /// HFR values for captured frames before averages
         QVector<double> HFRFrames;
-        // CCD Exposure Looping
-        bool rememberCCDExposureLooping = { false };
+        // Camera Fast Exposure
+        bool m_RememberCameraFastExposure = { false };
         // Future Watch
         QFutureWatcher<bool> m_StarFinderWatcher;
 
@@ -828,5 +844,8 @@ private slots:
 
         // Mount altitude value for logging
         double mountAlt { INVALID_VALUE };
+
+        // Dark Processor
+        QPointer<DarkProcessor> m_DarkProcessor;
 };
 }
