@@ -1,11 +1,8 @@
-/*  Ekos guide tool
-    Copyright (C) 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
+/*
+    SPDX-FileCopyrightText: 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
@@ -15,6 +12,7 @@
 #include "ekos/ekos.h"
 #include "indi/indiccd.h"
 #include "indi/inditelescope.h"
+#include "ekos/auxiliary/darkprocessor.h"
 
 #include <QTime>
 #include <QTimer>
@@ -371,8 +369,7 @@ class Guide : public QWidget, public Ui::Guide
         void setCaptureStatus(Ekos::CaptureState newState);
         // Update Mount module status
         void setMountStatus(ISD::Telescope::Status newState);
-        void setMountCoords(const QString &ra, const QString &dec, const QString &az, const QString &alt, int pierSide,
-                            const QString &ha);
+        void setMountCoords(const SkyPoint &position, ISD::Telescope::PierSide pierSide, const dms &ha);
 
         // Update Pier Side
         void setPierSide(ISD::Telescope::PierSide newSide);
@@ -562,8 +559,8 @@ class Guide : public QWidget, public Ui::Guide
         QVector3D starCenter;
 
         // Guide Params
-        //int guideBinIndex { 0 };
-        int guideFilterIndex { 0 };
+        int guideBinIndex { 0 };    // Selected or saved binning for guiding
+        int guideFilterIndex { 0 }; // Selected or saved filter for post-treatment
         double ccdPixelSizeX { -1 };
         double ccdPixelSizeY { -1 };
         double aperture { -1 };
@@ -630,6 +627,9 @@ class Guide : public QWidget, public Ui::Guide
         QPointer<FITSViewer> fv;
         QSharedPointer<FITSData> m_ImageData;
 
+        // Dark Processor
+        QPointer<DarkProcessor> m_DarkProcessor;
+
         double primaryFL = -1, primaryAperture = -1, guideFL = -1, guideAperture = -1;
         ISD::Telescope::Status m_MountStatus { ISD::Telescope::MOUNT_IDLE };
 
