@@ -1,12 +1,9 @@
-/*  Ekos guide drift graph plot widget
-    Copyright (C) 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
-                  2021 Wolfgang Reissenberger <sterne-jaeger@openfuture.de>
+/*
+    SPDX-FileCopyrightText: 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
+    SPDX-FileCopyrightText: 2021 Wolfgang Reissenberger <sterne-jaeger@openfuture.de>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "guidedriftgraph.h"
 #include "klocalizedstring.h"
