@@ -1,12 +1,8 @@
-/*  INDI Options
-    Copyright (C) 2003 Jasem Mutlaq (mutlaqja@ikarustech.com)
+/*
+    SPDX-FileCopyrightText: 2003 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "opsguide.h"
 
@@ -32,24 +28,6 @@ OpsGuide::OpsGuide() : QFrame(KStars::Instance())
     //Get a pointer to the KConfigDialog
     m_ConfigDialog = KConfigDialog::exists("guidesettings");
 
-    connect(kcfg_DitherNoGuiding, &QCheckBox::toggled, this, [&](bool checked)
-    {
-        if (checked && kcfg_DitherEnabled->isChecked())
-        {
-            KSNotification::error("Guided dithering cannot be used along with non-guided dithering.");
-            kcfg_DitherEnabled->setChecked(false);
-        }
-    });
-
-    connect(kcfg_DitherEnabled, &QCheckBox::toggled, this, [&](bool checked)
-    {
-        if (checked && kcfg_DitherNoGuiding->isChecked())
-        {
-            KSNotification::error("Guided dithering cannot be used along with non-guided dithering.");
-            kcfg_DitherNoGuiding->setChecked(false);
-        }
-    });
-
     editGuideProfile->setIcon(QIcon::fromTheme("document-edit"));
     editGuideProfile->setAttribute(Qt::WA_LayoutUsesWidgetRect);
 
@@ -80,8 +58,7 @@ OpsGuide::OpsGuide() : QFrame(KStars::Instance())
 
 void OpsGuide::loadOptionsProfiles()
 {
-    QString savedOptionsProfiles = KSPaths::writableLocation(QStandardPaths::GenericDataLocation) +
-                                   QString("SavedGuideProfiles.ini");
+    QString savedOptionsProfiles = QDir(KSPaths::writableLocation(QStandardPaths::AppDataLocation)).filePath("SavedGuideProfiles.ini");
     if(QFile(savedOptionsProfiles).exists())
         optionsList = StellarSolver::loadSavedOptionsProfiles(savedOptionsProfiles);
     else
