@@ -1,21 +1,10 @@
-/***************************************************************************
-                          FITSViewer.cpp  -  A FITSViewer for KStars
-                             -------------------
-    begin                : Thu Jan 22 2004
-    copyright            : (C) 2004 by Jasem Mutlaq
-    email                : mutlaqja@ikarustech.com
+/*
+    SPDX-FileCopyrightText: 2004 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
- 2006-03-03	Using CFITSIO, Porting to Qt4
- ***************************************************************************/
+    2006-03-03	Using CFITSIO, Porting to Qt4
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "fitsviewer.h"
 
@@ -562,6 +551,11 @@ bool FITSViewer::updateFITSCommon(FITSTab *tab, const QUrl &imageName)
     if (tab->isVisible())
         led.setColor(Qt::green);
 
+    if (tab->shouldComputeHFR())
+        updateStatusBar(HFRStatusString(tab->getView()->imageData()), FITS_HFR);
+    else
+        updateStatusBar("", FITS_HFR);
+
     return true;
 }
 
