@@ -1,15 +1,8 @@
-/*  Device Manager
-    Copyright (C) 2003 Jasem Mutlaq (mutlaqja@ikarustech.com)
+/*
+    SPDX-FileCopyrightText: 2003 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    JM Changelog
-    2004-16-1:	Start
-
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "devicemanager.h"
 
