@@ -1,12 +1,8 @@
-/*  INDI Server Manager
-    Copyright (C) 2012 Jasem Mutlaq (mutlaqja@ikarustech.com)
+/*
+    SPDX-FileCopyrightText: 2012 Jasem Mutlaq <mutlaqja@ikarustech.com>
 
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "drivermanager.h"
 
@@ -56,15 +52,16 @@ DriverManagerUI::DriverManagerUI(QWidget *parent) : QFrame(parent)
     connected    = QIcon::fromTheme("network-connect");
     disconnected = QIcon::fromTheme("network-disconnect");
 
-    connect(localTreeWidget, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), this,
-            SLOT(makePortEditable(QTreeWidgetItem*, int)));
+    connect(localTreeWidget, &QTreeWidget::itemDoubleClicked, this,
+            &DriverManagerUI::makePortEditable);
 }
 
 void DriverManagerUI::makePortEditable(QTreeWidgetItem *selectedItem, int column)
 {
     // If it's the port column, then make it user-editable
     if (column == ::DriverManager::LOCAL_PORT_COLUMN)
-        selectedItem->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable | Qt::ItemIsEnabled);
+        selectedItem->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEditable |
+                               Qt::ItemIsEnabled);
 
     localTreeWidget->editItem(selectedItem, ::DriverManager::LOCAL_PORT_COLUMN);
 }
@@ -75,7 +72,7 @@ DriverManager *DriverManager::Instance()
 {
     if (_DriverManager == nullptr)
     {
-        _DriverManager = new DriverManager(KStars::Instance());
+        _DriverManager     = new DriverManager(KStars::Instance());
         INDIDBus *indiDBUS = new INDIDBus(KStars::Instance());
         Q_UNUSED(indiDBUS)
     }
@@ -95,29 +92,30 @@ DriverManager::DriverManager(QWidget *parent) : QDialog(parent)
     ui                      = new DriverManagerUI(this);
     mainLayout->addWidget(ui);
     setLayout(mainLayout);
-    setWindowTitle(i18n("Device Manager"));
+    setWindowTitle(i18nc("@title:window", "Device Manager"));
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
     mainLayout->addWidget(buttonBox);
 
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(close()));
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &DriverManager::close);
 
-    connect(ui->addB, SIGNAL(clicked()), this, SLOT(addINDIHost()));
-    connect(ui->modifyB, SIGNAL(clicked()), this, SLOT(modifyINDIHost()));
-    connect(ui->removeB, SIGNAL(clicked()), this, SLOT(removeINDIHost()));
+    connect(ui->addB, &QPushButton::clicked, this, &DriverManager::addINDIHost);
+    connect(ui->modifyB, &QPushButton::clicked, this, &DriverManager::modifyINDIHost);
+    connect(ui->removeB, &QPushButton::clicked, this, &DriverManager::removeINDIHost);
 
-    connect(ui->connectHostB, SIGNAL(clicked()), this, SLOT(activateHostConnection()));
-    connect(ui->disconnectHostB, SIGNAL(clicked()), this, SLOT(activateHostDisconnection()));
-    connect(ui->runServiceB, SIGNAL(clicked()), this, SLOT(activateRunService()));
-    connect(ui->stopServiceB, SIGNAL(clicked()), this, SLOT(activateStopService()));
-    connect(ui->localTreeWidget, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(updateLocalTab()));
-    connect(ui->clientTreeWidget, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(updateClientTab()));
-    connect(ui->localTreeWidget, SIGNAL(expanded(QModelIndex)), this, SLOT(resizeDeviceColumn()));
+    connect(ui->connectHostB, &QPushButton::clicked, this, &DriverManager::activateHostConnection);
+    connect(ui->disconnectHostB, &QPushButton::clicked, this, &DriverManager::activateHostDisconnection);
+    connect(ui->runServiceB, &QPushButton::clicked, this, &DriverManager::activateRunService);
+    connect(ui->stopServiceB, &QPushButton::clicked, this, &DriverManager::activateStopService);
+    connect(ui->localTreeWidget,  &QTreeWidget::itemClicked, this, &DriverManager::updateLocalTab);
+    connect(ui->clientTreeWidget, &QTreeWidget::itemClicked, this, &DriverManager::updateClientTab);
+    connect(ui->localTreeWidget, &QTreeWidget::expanded, this, &DriverManager::resizeDeviceColumn);
 
     // Do not use KSPaths here, this is for INDI
     if (Options::indiDriversDir().isEmpty())
         Options::setIndiDriversDir(
-            QStandardPaths::locate(QStandardPaths::GenericDataLocation, "indi", QStandardPaths::LocateDirectory));
+            QStandardPaths::locate(QStandardPaths::GenericDataLocation, "indi",
+                                   QStandardPaths::LocateDirectory));
 
     readXMLDrivers();
 
@@ -157,7 +155,8 @@ void DriverManager::processDeviceStatus(DriverInfo *dv)
         if (ui->localTreeWidget->currentItem())
             currentDriver = ui->localTreeWidget->currentItem()->text(LOCAL_NAME_COLUMN);
 
-        for (auto &item : ui->localTreeWidget->findItems(dv->getLabel(), Qt::MatchExactly | Qt::MatchRecursive))
+        for (auto &item : ui->localTreeWidget->findItems(
+                    dv->getLabel(), Qt::MatchExactly | Qt::MatchRecursive))
         {
             item->setText(LOCAL_VERSION_COLUMN, dv->getVersion());
 
@@ -169,7 +168,8 @@ void DriverManager::processDeviceStatus(DriverInfo *dv)
 
             bool locallyAvailable = false;
             if (dv->getAuxInfo().contains("LOCALLY_AVAILABLE"))
-                locallyAvailable = dv->getAuxInfo().value("LOCALLY_AVAILABLE", false).toBool();
+                locallyAvailable =
+                    dv->getAuxInfo().value("LOCALLY_AVAILABLE", false).toBool();
 
             switch (mode)
             {
@@ -178,7 +178,8 @@ void DriverManager::processDeviceStatus(DriverInfo *dv)
                     {
                         ui->runServiceB->setEnabled(!dState);
                         ui->stopServiceB->setEnabled(dState);
-                        item->setIcon(LOCAL_STATUS_COLUMN, dState ? ui->runningPix : ui->stopPix);
+                        item->setIcon(LOCAL_STATUS_COLUMN,
+                                      dState ? ui->runningPix : ui->stopPix);
                     }
                     else
                     {
@@ -205,7 +206,8 @@ void DriverManager::processDeviceStatus(DriverInfo *dv)
                     {
                         ui->runServiceB->setEnabled(!cState);
                         ui->stopServiceB->setEnabled(cState);
-                        item->setIcon(LOCAL_STATUS_COLUMN, cState ? ui->runningPix : ui->stopPix);
+                        item->setIcon(LOCAL_STATUS_COLUMN,
+                                      cState ? ui->runningPix : ui->stopPix);
                     }
                     else
                     {
@@ -223,7 +225,8 @@ void DriverManager::processDeviceStatus(DriverInfo *dv)
                     else
                     {
                         item->setIcon(LOCAL_MODE_COLUMN, QIcon());
-                        item->setText(LOCAL_PORT_COLUMN, dv->getUserPort() == "-1" ? "" : dv->getUserPort());
+                        item->setText(LOCAL_PORT_COLUMN,
+                                      dv->getUserPort() == "-1" ? "" : dv->getUserPort());
                     }
 
                     break;
@@ -239,7 +242,8 @@ void DriverManager::processDeviceStatus(DriverInfo *dv)
     }
     else
     {
-        for (auto &item : ui->clientTreeWidget->findItems(dv->getName(), Qt::MatchExactly, HOST_NAME_COLUMN))
+        for (auto &item : ui->clientTreeWidget->findItems(dv->getName(), Qt::MatchExactly,
+                HOST_NAME_COLUMN))
         {
             if (dv->getClientState())
             {
@@ -257,7 +261,8 @@ void DriverManager::processDeviceStatus(DriverInfo *dv)
     }
 }
 
-void DriverManager::getUniqueHosts(QList<DriverInfo *> &dList, QList<QList<DriverInfo *>> &uHosts)
+void DriverManager::getUniqueHosts(QList<DriverInfo *> &dList,
+                                   QList<QList<DriverInfo *>> &uHosts)
 {
     bool found = false;
 
@@ -270,13 +275,15 @@ void DriverManager::getUniqueHosts(QList<DriverInfo *> &dList, QList<QList<Drive
         for (DriverInfo *idv : dList)
         {
             // If we get a match between port and hostname, we add it to the list
-            if ( (dv->getHost() == idv->getHost() && dv->getPort() == idv->getPort()))
+            if ((dv->getHost() == idv->getHost() && dv->getPort() == idv->getPort()))
             {
                 // Check if running already
                 if (dv->getClientState() || dv->getServerState())
                 {
                     int ans = KMessageBox::warningContinueCancel(
-                                  nullptr, i18n("Driver %1 is already running, do you want to restart it?", dv->getLabel()));
+                                  nullptr,
+                                  i18n("Driver %1 is already running, do you want to restart it?",
+                                       dv->getLabel()));
                     if (ans == KMessageBox::Cancel)
                         continue;
                     else
@@ -390,8 +397,8 @@ bool DriverManager::startDevices(QList<DriverInfo *> &dList)
         for (DriverInfo *dv : qdv)
             clientManager->appendManagedDriver(dv);
 
-        connect(clientManager, SIGNAL(connectionFailure(ClientManager*)), this,
-                SLOT(processClientTermination(ClientManager*)));
+        connect(clientManager, &ClientManager::connectionFailure, this,
+                &DriverManager::processClientTermination);
 
         clientManager->setServer(qdv.at(0)->getHost().toLatin1().constData(), port);
 
@@ -400,7 +407,8 @@ bool DriverManager::startDevices(QList<DriverInfo *> &dList)
 
         for (int i = 0; i < INDI_MAX_TRIES; i++)
         {
-            qCDebug(KSTARS_INDI) << "INDI: Connecting to local INDI server on port " << port << " ...";
+            qCDebug(KSTARS_INDI)
+                    << "INDI: Connecting to local INDI server on port " << port << " ...";
 
             connectionToServer = clientManager->connectServer();
 
@@ -422,14 +430,16 @@ bool DriverManager::startDevices(QList<DriverInfo *> &dList)
         }
         else
         {
-            qCDebug(KSTARS_INDI) << "INDI: Connection to local INDI server on port " << port << " failed!";
+            qCDebug(KSTARS_INDI)
+                    << "INDI: Connection to local INDI server on port " << port << " failed!";
 
             KNotification::beep();
             QPointer<QMessageBox> msgBox = new QMessageBox();
             msgBox->setAttribute(Qt::WA_DeleteOnClose);
             msgBox->setStandardButtons(QMessageBox::Ok);
-            msgBox->setWindowTitle(i18n("Error"));
-            msgBox->setText(i18n("Connection to INDI server locally on port %1 failed.", port));
+            msgBox->setWindowTitle(i18nc("@title:window", "Error"));
+            msgBox->setText(
+                i18n("Connection to INDI server locally on port %1 failed.", port));
             msgBox->setModal(false);
             msgBox->setIcon(QMessageBox::Critical);
             msgBox->show();
@@ -584,7 +594,8 @@ void DriverManager::processLocalTree(bool dState)
             port = -1;
 
             //device->state = (dev_request == DriverInfo::DEV_TERMINATE) ? DriverInfo::DEV_START : DriverInfo::DEV_TERMINATE;
-            if (item->text(LOCAL_NAME_COLUMN) == device->getLabel() && device->getServerState() != dState)
+            if (item->text(LOCAL_NAME_COLUMN) == device->getLabel() &&
+                    device->getServerState() != dState)
             {
                 processed_devices.append(device);
 
@@ -597,7 +608,8 @@ void DriverManager::processLocalTree(bool dState)
                     // If we encounter conversion error, we abort
                     if (portOK == false)
                     {
-                        KSNotification::error(i18n("Invalid port entry: %1", item->text(LOCAL_PORT_COLUMN)));
+                        KSNotification::error(i18n("Invalid port entry: %1",
+                                                   item->text(LOCAL_PORT_COLUMN)));
                         return;
                     }
                 }
@@ -634,8 +646,11 @@ void DriverManager::processClientTermination(ClientManager *client)
     GUIManager::Instance()->removeClient(client);
     INDIListener::Instance()->removeClient(client);
 
-    KSNotification::error(i18n("Connection to INDI host at %1 on port %2 lost. Server disconnected.", client->getHost(),
-                               client->getPort()));
+    KSNotification::event(
+        QLatin1String("IndiServerMessage"),
+        i18n("Connection to INDI host at %1 on port %2 lost. Server disconnected.",
+             client->getHost(), client->getPort()),
+        KSNotification::EVENT_ALERT);
 
     clients.removeOne(client);
     client->deleteLater();
@@ -657,8 +672,9 @@ void DriverManager::processServerTermination(ServerManager *server)
 
     if (server->getMode() == SERVER_ONLY)
     {
-        KSNotification::error(i18n("Connection to INDI host at %1 on port %2 encountered an error: %3.",
-                                   server->getHost(), server->getPort(), server->errorString()));
+        KSNotification::error(
+            i18n("Connection to INDI host at %1 on port %2 encountered an error: %3.",
+                 server->getHost(), server->getPort(), server->errorString()));
     }
 
     emit serverTerminated(server->getHost(), server->getPort());
@@ -717,10 +733,11 @@ bool DriverManager::connectRemoteHost(DriverInfo *dv)
 
     clientManager->appendManagedDriver(dv);
 
-    connect(clientManager, SIGNAL(connectionFailure(ClientManager*)), this,
-            SLOT(processClientTermination(ClientManager*)));
+    connect(clientManager, &ClientManager::connectionFailure, this,
+            &DriverManager::processClientTermination);
 
-    clientManager->setServer(dv->getHost().toLatin1().constData(), static_cast<uint>(dv->getPort().toInt()));
+    clientManager->setServer(dv->getHost().toLatin1().constData(),
+                             static_cast<uint>(dv->getPort().toInt()));
 
     GUIManager::Instance()->addClient(clientManager);
     INDIListener::Instance()->addClient(clientManager);
@@ -740,25 +757,17 @@ bool DriverManager::connectRemoteHost(DriverInfo *dv)
         clients.append(clientManager);
         updateMenuActions();
 
-        KSNotification::event(QLatin1String("ConnectionSuccessful"), i18n("Connected to INDI server"), KSNotification::EVENT_ALERT);
+        KSNotification::event(QLatin1String("ConnectionSuccessful"),
+                              i18n("Connected to INDI server"),
+                              KSNotification::EVENT_INFO);
     }
     else
     {
         GUIManager::Instance()->removeClient(clientManager);
         INDIListener::Instance()->removeClient(clientManager);
 
-        KNotification::beep();
-        QMessageBox *msgBox = new QMessageBox();
-        msgBox->setAttribute(Qt::WA_DeleteOnClose);
-        msgBox->setStandardButtons(QMessageBox::Ok);
-        msgBox->setWindowTitle(i18n("Error"));
-        msgBox->setText(
-            i18n("Connection to INDI server at host %1 with port %2 failed.", dv->getHost(), dv->getPort()));
-        KSNotification::event(QLatin1String("ConnectionFailed"), msgBox->text(), KSNotification::EVENT_ALERT);
-        msgBox->setModal(false);
-        msgBox->setIcon(QMessageBox::Critical);
-        msgBox->show();
-
+        KSNotification::error(i18n("Connection to INDI server at host %1 with port %2 failed.",
+                                   dv->getHost(), dv->getPort()), i18nc("@title:window", "Error"), 30);
         processDeviceStatus(dv);
         return false;
     }
@@ -863,7 +872,7 @@ bool DriverManager::readINDIHosts()
     QString hName, hHost, hPort;
 
     lastGroup = nullptr;
-    file.setFileName(KSPaths::locate(QStandardPaths::GenericDataLocation, indiFile));
+    file.setFileName(KSPaths::locate(QStandardPaths::AppDataLocation, indiFile));
     if (file.fileName().isEmpty() || !file.open(QIODevice::ReadOnly))
     {
         delLilXML(xmlParser);
@@ -911,7 +920,7 @@ bool DriverManager::readINDIHosts()
             dv->setHostParameters(hHost, hPort);
             dv->setDriverSource(HOST_SOURCE);
 
-            connect(dv, SIGNAL(deviceStateChanged(DriverInfo*)), this, SLOT(processDeviceStatus(DriverInfo*)));
+            connect(dv, &DriverInfo::deviceStateChanged, this, &DriverManager::processDeviceStatus);
 
             driversList.append(dv);
 
@@ -942,7 +951,7 @@ bool DriverManager::readXMLDrivers()
     QString driverName;
 
     // This is the XML file shipped with KStars that contains all supported INDI drivers.
-    /*QString indiDriversXML = KSPaths::locate(QStandardPaths::GenericDataLocation, "indidrivers.xml");
+    /*QString indiDriversXML = KSPaths::locate(QStandardPaths::AppDataLocation, "indidrivers.xml");
     if (indiDriversXML.isEmpty() == false)
         processXMLDriver(indiDriversXML);
     */
@@ -952,18 +961,21 @@ bool DriverManager::readXMLDrivers()
     QString driversDir = Options::indiDriversDir();
 #ifdef Q_OS_OSX
     if (Options::indiDriversAreInternal())
-        driversDir = QCoreApplication::applicationDirPath() + "/../Resources/DriverSupport";
+        driversDir =
+            QCoreApplication::applicationDirPath() + "/../Resources/DriverSupport";
 #endif
 
     if (indiDir.cd(driversDir) == false)
     {
-        KSNotification::error(i18n("Unable to find INDI Drivers directory: %1\nPlease make sure to set the correct "
+        KSNotification::error(i18n("Unable to find INDI drivers directory: %1\nPlease "
+                                   "make sure to set the correct "
                                    "path in KStars configuration",
                                    driversDir));
         return false;
     }
 
-    indiDir.setNameFilters(QStringList() << "indi_*.xml" << "drivers.xml");
+    indiDir.setNameFilters(QStringList() << "indi_*.xml"
+                           << "drivers.xml");
     indiDir.setFilter(QDir::Files | QDir::NoSymLinks);
     QFileInfoList list = indiDir.entryInfoList();
 
@@ -976,7 +988,7 @@ bool DriverManager::readXMLDrivers()
         //        if (fileInfo.fileName() == "drivers.xml")
         //        {
         //            // Let first attempt to load the local version of drivers.xml
-        //            driverName = KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + "drivers.xml";
+        //            driverName = QDir(KSPaths::writableLocation(QStandardPaths::AppDataLocation)).filePath("drivers.xml");
 
         //            // If found, we continue, otherwise, we load the system file
         //            if (driverName.isEmpty() == false && QFile(driverName).exists())
@@ -1064,7 +1076,8 @@ bool DriverManager::buildDeviceGroup(XMLEle *root, char errmsg[])
 
     if (!ap)
     {
-        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a group attribute", tagXMLEle(root));
+        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a group attribute",
+                 tagXMLEle(root));
         return false;
     }
 
@@ -1078,7 +1091,8 @@ bool DriverManager::buildDeviceGroup(XMLEle *root, char errmsg[])
 #endif
 
     // Find if the group already exists
-    QList<QTreeWidgetItem *> treeList = ui->localTreeWidget->findItems(groupName, Qt::MatchExactly);
+    QList<QTreeWidgetItem *> treeList =
+        ui->localTreeWidget->findItems(groupName, Qt::MatchExactly);
     if (!treeList.isEmpty())
         group = treeList[0];
     else
@@ -1096,7 +1110,8 @@ bool DriverManager::buildDeviceGroup(XMLEle *root, char errmsg[])
     return true;
 }
 
-bool DriverManager::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, DeviceFamily groupType, char errmsg[])
+bool DriverManager::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup,
+                                       DeviceFamily groupType, char errmsg[])
 {
     XMLAtt *ap;
     XMLEle *el;
@@ -1115,7 +1130,8 @@ bool DriverManager::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, De
     ap = findXMLAtt(root, "label");
     if (!ap)
     {
-        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a label attribute", tagXMLEle(root));
+        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a label attribute",
+                 tagXMLEle(root));
         return false;
     }
 
@@ -1176,7 +1192,8 @@ bool DriverManager::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, De
     ap = findXMLAtt(el, "name");
     if (!ap)
     {
-        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a name attribute", tagXMLEle(el));
+        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a name attribute",
+                 tagXMLEle(el));
         return false;
     }
 
@@ -1187,7 +1204,7 @@ bool DriverManager::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, De
     if (!el)
         return false;
 
-    version = pcdataXMLEle(el);
+    version        = pcdataXMLEle(el);
     bool versionOK = false;
     version.toDouble(&versionOK);
     if (versionOK == false)
@@ -1224,7 +1241,7 @@ bool DriverManager::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, De
     dv->setUserPort(port);
     dv->setAuxInfo(vMap);
 
-    connect(dv, SIGNAL(deviceStateChanged(DriverInfo*)), this, SLOT(processDeviceStatus(DriverInfo*)));
+    connect(dv, &DriverInfo::deviceStateChanged, this, &DriverManager::processDeviceStatus);
 
     driversList.append(dv);
 
@@ -1269,7 +1286,6 @@ void DriverManager::updateCustomDrivers()
     }
 }
 
-
 // JM 2018-07-23: Disabling the old custom drivers method
 #if 0
 void DriverManager::updateCustomDrivers()
@@ -1374,7 +1390,7 @@ void DriverManager::addINDIHost()
     QDialog hostConfDialog;
     Ui::INDIHostConf hostConf;
     hostConf.setupUi(&hostConfDialog);
-    hostConfDialog.setWindowTitle(i18n("Add Host"));
+    hostConfDialog.setWindowTitle(i18nc("@title:window", "Add Host"));
     bool portOk = false;
 
     if (hostConfDialog.exec() == QDialog::Accepted)
@@ -1390,22 +1406,24 @@ void DriverManager::addINDIHost()
             return;
         }
 
-        hostItem->setHostParameters(hostConf.hostname->text(), hostConf.portnumber->text());
+        hostItem->setHostParameters(hostConf.hostname->text(),
+                                    hostConf.portnumber->text());
 
         //search for duplicates
         //for (uint i=0; i < ksw->data()->INDIHostsList.count(); i++)
         foreach (DriverInfo *host, driversList)
-            if (hostItem->getName() == host->getName() && hostItem->getPort() == host->getPort())
+            if (hostItem->getName() == host->getName() &&
+                    hostItem->getPort() == host->getPort())
             {
-                KSNotification::error(
-                    i18n("Host: %1 Port: %2 already exists.", hostItem->getName(), hostItem->getPort()));
+                KSNotification::error(i18n("Host: %1 Port: %2 already exists.",
+                                           hostItem->getName(), hostItem->getPort()));
                 delete hostItem;
                 return;
             }
 
         hostItem->setDriverSource(HOST_SOURCE);
 
-        connect(hostItem, SIGNAL(deviceStateChanged(DriverInfo*)), this, SLOT(processDeviceStatus(DriverInfo*)));
+        connect(hostItem, &DriverInfo::deviceStateChanged, this, &DriverManager::processDeviceStatus);
 
         driversList.append(hostItem);
 
@@ -1423,7 +1441,7 @@ void DriverManager::modifyINDIHost()
     QDialog hostConfDialog;
     Ui::INDIHostConf hostConf;
     hostConf.setupUi(&hostConfDialog);
-    hostConfDialog.setWindowTitle(i18n("Modify Host"));
+    hostConfDialog.setWindowTitle(i18nc("@title:window", "Modify Host"));
 
     QTreeWidgetItem *currentItem = ui->clientTreeWidget->currentItem();
 
@@ -1443,7 +1461,8 @@ void DriverManager::modifyINDIHost()
             {
                 //INDIHostsInfo *hostItem = new INDIHostsInfo;
                 host->setName(hostConf.nameIN->text());
-                host->setHostParameters(hostConf.hostname->text(), hostConf.portnumber->text());
+                host->setHostParameters(hostConf.hostname->text(),
+                                        hostConf.portnumber->text());
 
                 currentItem->setText(HOST_NAME_COLUMN, hostConf.nameIN->text());
                 currentItem->setText(HOST_PORT_COLUMN, hostConf.portnumber->text());
@@ -1463,20 +1482,24 @@ void DriverManager::removeINDIHost()
         return;
 
     foreach (DriverInfo *host, driversList)
-        if (ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN) == host->getName() &&
-                ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) == host->getPort())
+        if (ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN) ==
+                host->getName() &&
+                ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) ==
+                host->getPort())
         {
             if (host->getClientState())
             {
-                KSNotification::error(i18n("You need to disconnect the client before removing it."));
+                KSNotification::error(
+                    i18n("You need to disconnect the client before removing it."));
                 return;
             }
 
-            if (KMessageBox::warningContinueCancel(nullptr,
-                                                   i18n("Are you sure you want to remove the %1 client?",
-                                                           ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN)),
-                                                   i18n("Delete Confirmation"),
-                                                   KStandardGuiItem::del()) != KMessageBox::Continue)
+            if (KMessageBox::warningContinueCancel(
+                        nullptr,
+                        i18n("Are you sure you want to remove the %1 client?",
+                             ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN)),
+                        i18n("Delete Confirmation"),
+                        KStandardGuiItem::del()) != KMessageBox::Continue)
                 return;
 
             driversList.removeOne(host);
@@ -1493,15 +1516,15 @@ void DriverManager::saveHosts()
     QFile file;
     QString hostData;
 
-    file.setFileName(KSPaths::writableLocation(QStandardPaths::GenericDataLocation) +
-                     "indihosts.xml"); //determine filename in local user KDE directory tree.
+    //determine filename in local user KDE directory tree.
+    file.setFileName(QDir(KSPaths::writableLocation(QStandardPaths::AppDataLocation))
+                     .filePath("indihosts.xml"));
 
     if (!file.open(QIODevice::WriteOnly))
     {
-        KSNotification::sorry(
-            i18n(
-                "Unable to write to file 'indihosts.xml'\nAny changes to INDI hosts configurations will not be saved."),
-            i18n("Could Not Open File"));
+        KSNotification::sorry(i18n("Unable to write to file 'indihosts.xml'\nAny changes "
+                                   "to INDI hosts configurations will not be saved."),
+                              i18n("Could Not Open File"));
         return;
     }
 
