@@ -1,18 +1,8 @@
-/***************************************************************************
-                          INDI Driver
-                             -------------------
-    begin                : Wed May 7th 2003
-    copyright            : (C) 2001 by Jasem Mutlaq
-    email                : mutlaqja@ikarustech.com
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Jasem Mutlaq <mutlaqja@ikarustech.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
