@@ -1,19 +1,8 @@
-/***************************************************************************
-                          kstarsdata.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : Sun Jul 29 2001
-    copyright            : (C) 2001 by Heiko Evermann
-    email                : heiko@evermann.de
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Heiko Evermann <heiko@evermann.de>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kstarsdata.h"
 
