@@ -1,19 +1,8 @@
-/***************************************************************************
-                          main.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : Mon Feb  5 01:11:45 PST 2001
-    copyright            : (C) 2001 by Jason Harris
-    email                : jharris@30doradus.org
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Jason Harris <jharris@30doradus.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ksnumbers.h"
 #include "kspaths.h"
@@ -366,6 +355,12 @@ int main(int argc, char *argv[])
 
 #endif
 
+    // Create writable data dir if it does not exist
+    QDir(KSPaths::writableLocation(QStandardPaths::AppDataLocation)).mkpath(".");
+    QDir(KSPaths::writableLocation(QStandardPaths::AppConfigLocation)).mkpath(".");
+    QDir(KSPaths::writableLocation(QStandardPaths::CacheLocation)).mkpath(".");
+    QDir(KSPaths::writableLocation(QStandardPaths::TempLocation)).mkpath(qAppName());
+
 #ifndef KSTARS_LITE
     KStars::createInstance(true, !parser.isSet("paused"), datestring);
 
