@@ -1,19 +1,9 @@
-/***************************************************************************
-                catalogscomponent.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : Jun 2021
-    copyright            : (C) 2021 by Valentin Boettcher, Jason Harris
-    email                : hiro at protagon.space; @hiro98:tchncs.de
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Jason Harris <jharris@30doradus.org>
+    SPDX-FileCopyrightText: 2021 Valentin Boettcher <hiro at protagon.space; @hiro98:tchncs.de>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <cmath>
 #include "catalogscomponent.h"
