@@ -1,19 +1,8 @@
-/***************************************************************************
-                          kscomet.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : Wed 19 Feb 2003
-    copyright            : (C) 2001 by Jason Harris
-    email                : jharris@30doradus.org
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Jason Harris <jharris@30doradus.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kscomet.h"
 
@@ -58,21 +47,24 @@ KSComet::KSComet(const QString &_s, const QString &imfile, double _q, double _e,
 
     //Find the Julian Day of Perihelion from Tp
     //Tp is a double which encodes a date like: YYYYMMDD.DDDDD (e.g., 19730521.33333
-    int year    = int(Tp / 10000.0);
-    int month   = int((int(Tp) % 10000) / 100.0);
-    int day     = int(int(Tp) % 100);
-    double Hour = 24.0 * (Tp - int(Tp));
-    int h       = int(Hour);
-    int m       = int(60.0 * (Hour - h));
-    int s       = int(60.0 * (60.0 * (Hour - h) - m));
+    //    int year    = int(Tp / 10000.0);
+    //    int month   = int((int(Tp) % 10000) / 100.0);
+    //    int day     = int(int(Tp) % 100);
+    //    double Hour = 24.0 * (Tp - int(Tp));
+    //    int h       = int(Hour);
+    //    int m       = int(60.0 * (Hour - h));
+    //    int s       = int(60.0 * (60.0 * (Hour - h) - m));
 
-    JDp   = KStarsDateTime(QDate(year, month, day), QTime(h, m, s)).djd();
+    //JDp   = KStarsDateTime(QDate(year, month, day), QTime(h, m, s)).djd();
+
+    // JM 2021.10.21: In the new JPL format, it's already in JD
+    JDp = Tp;
 
     //compute the semi-major axis, a:
     if (e == 1)
         a = 0;
     else
-        a = q / (1.0-e);
+        a = q / (1.0 - e);
 
 
     //Compute the orbital Period from Kepler's 3rd law:
@@ -145,7 +137,7 @@ void KSComet::findPhysicalParameters()
 {
     // Compute and store the estimated Physical size of the comet's coma, tail and nucleus
     // References:
-    // * http://www.projectpluto.com/update7b.htm#comet_tail_formula [Project Pluto / GUIDE]
+    // * https://www.projectpluto.com/update7b.htm#comet_tail_formula [Project Pluto / GUIDE]
     // * http://articles.adsabs.harvard.edu//full/1978BAICz..29..103K/0000113.000.html [Kresak, 1978a, "Passages of comets and asteroids near the earth"]
     NuclearSize   = pow(10, 2.1 - 0.2 * M1);
     double mHelio = M1 + K1 * log10(rsun());
@@ -167,8 +159,6 @@ bool KSComet::findGeocentricPosition(const KSNumbers *num, const KSPlanetBase *E
 
     // Different between lastJD and Tp (Time of periapsis (Julian Day Number))
     long double deltaJDP = lastPrecessJD - JDp;
-    // Limit it to last orbit
-    //while (deltaJDP > P) deltaJDP -= P;
 
     if (e > 0.98)
     {
@@ -212,8 +202,9 @@ bool KSComet::findGeocentricPosition(const KSNumbers *num, const KSPlanetBase *E
                 E0 = E;
                 iter++;
                 E = E0 - (E0 - e * 180.0 / dms::PI * sin(E0 * dms::DegToRad) - m.Degrees()) /
-                             (1 - e * cos(E0 * dms::DegToRad));
-            } while (fabs(E - E0) > 0.001 && iter < 1000);
+                    (1 - e * cos(E0 * dms::DegToRad));
+            }
+            while (fabs(E - E0) > 0.001 && iter < 1000);
         }
 
         // Assert that the solution of the Kepler equation E = M + e sin E is accurate to about 0.1 arcsecond
@@ -296,10 +287,6 @@ bool KSComet::findGeocentricPosition(const KSNumbers *num, const KSPlanetBase *E
     setRA0(ra());
     setDec0(dec());
     apparentCoord(J2000, lastPrecessJD);
-
-    //nutate(num);
-    //aberrate(num);
-
     findPhysicalParameters();
 
     return true;
