@@ -1,19 +1,8 @@
-/***************************************************************************
-                          simclock.h  -  description
-                             -------------------
-    begin                : Mon Feb 18 2002
-    copyright          : (C) 2002 by Mark Hollomon
-    email                : mhh@mindspring.com
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002 Mark Hollomon <mhh@mindspring.com>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #pragma once
 
