@@ -1,19 +1,8 @@
-/***************************************************************************
-                          modcalcequinox.cpp  -  description
-                             -------------------
-    begin                : dom may 2 2004
-    copyright            : (C) 2004-2005 by Pablo de Vicente
-    email                : p.devicentea@wanadoo.es
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004-2005 Pablo de Vicente <p.devicentea@wanadoo.es>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "modcalcplanets.h"
 
