@@ -1,21 +1,11 @@
-/***************************************************************************
-                          observinglist.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : 29 Nov 2004
-    copyright            : (C) 2004-2020 by Jeff Woods, Jason Harris,
-                           Prakash Mohan, Akarsh Simha
-    email                : jcwoods@bellsouth.net, jharris@30doradus.org,
-                           prakash.mohan@kdemail.net, akarsh@kde.org
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004-2020 Jeff Woods <jcwoods@bellsouth.net>
+    SPDX-FileCopyrightText: 2004-2020 Jason Harris <jharris@30doradus.org>
+    SPDX-FileCopyrightText: Prakash Mohan <prakash.mohan@kdemail.net>
+    SPDX-FileCopyrightText: Akarsh Simha <akarsh@kde.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "observinglist.h"
 
