@@ -1,18 +1,8 @@
-/***************************************************************************
-                          opsxplanet.cpp  -  K Desktop Planetarium
-                             -------------------
-    begin                : Wed 26 Nov 2008
-    copyright            : (C) 2008 by Jerome SONRIER
-    email                : jsid@emor3j.fr.eu.org
- ***************************************************************************/
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Jerome SONRIER <jsid@emor3j.fr.eu.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "opsxplanet.h"
 
